==> qmmp-plugin-pack-0.10.3.tar.bz2: qmmp-plugin-pack-0.10.3/src/Effect/srconverter/translations/srconverter_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="32"/>
        <source>SRC Plugin</source>
        <translation>SRC Module</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="53"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>Over de Sample Rate Converter Module</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="54"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Sample Rate Converter Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Sample Rate Converter Module Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation>Sample frequentie (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation>Interpolatie Engine:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation>Beste Sinc Interpolatie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation>Medium Sinc Interpolatie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>Snelste Sinc Interpolatie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation>ZOH Interpolatie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation>Lineaire Interpolatie</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-0.12.2.tar.bz2: qmmp-plugin-pack-0.12.2/src/Effect/srconverter/translations/srconverter_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="31"/>
        <source>SRC Plugin</source>
        <translation>SRC Module</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>Over de Sample Rate Converter Module</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="53"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Sample Rate Converter Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Sample Rate Converter Module Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Sample Rate (Hz):</source>
        <translation>Sample frequentie (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Interpolation Engine:</source>
        <translation>Interpolatie Engine:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Best Sinc Interpolation</source>
        <translation>Beste Sinc Interpolatie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Medium Sinc Interpolation</source>
        <translation>Medium Sinc Interpolatie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>Snelste Sinc Interpolatie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>ZOH Interpolation</source>
        <translation>ZOH Interpolatie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Linear Interpolation</source>
        <translation>Lineaire Interpolatie</translation>
    </message>
</context>
</TS>
